==> rpclib-2.2.2-beta.tar.gz: rpclib-2.2.2-beta/src/rpclib/client/zeromq.py <==

#
# rpclib - Copyright (C) Rpclib contributors.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301
#

"""A soap client that uses ZeroMQ (zmq.REQ) as transport"""

import zmq

import rpclib.protocol.soap

from rpclib.client import Service
from rpclib.client import RemoteProcedureBase
from rpclib.client import ClientBase

context = zmq.Context()

class _RemoteProcedure(RemoteProcedureBase):
    def __call__(self, *args, **kwargs):
        self.get_out_object(args, kwargs)
        self.get_out_string()
        out_string = ''.join(self.ctx.out_string)

        socket = context.socket(zmq.REQ)
        socket.connect(self.url)
        socket.send(out_string)

        self.ctx.in_string = socket.recv()
        self.get_in_object()

        if not (self.ctx.in_error is None):
            raise self.ctx.in_error
        else:
            return self.ctx.in_object

class Client(ClientBase):
    def __init__(self, url, app):
        ClientBase.__init__(self, url, app)

        # FIXME: this four-line block should be explained...
        if isinstance(app.in_protocol,rpclib.protocol.soap.Soap11):
            app.in_protocol.in_wrapper = rpclib.protocol.soap.Soap11.OUT_WRAPPER
        if isinstance(app.out_protocol,rpclib.protocol.soap.Soap11):
            app.out_protocol.out_wrapper= rpclib.protocol.soap.Soap11.NO_WRAPPER

        self.service = Service(_RemoteProcedure, url, app)

==> rpclib-2.3.1-beta.tar.gz: rpclib-2.3.1-beta/src/rpclib/client/zeromq.py <==

#
# rpclib - Copyright (C) Rpclib contributors.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301
#

"""A soap client that uses ZeroMQ (zmq.REQ) as transport"""

import zmq

import rpclib.protocol.soap

from rpclib.client import Service
from rpclib.client import RemoteProcedureBase
from rpclib.client import ClientBase

context = zmq.Context()

class _RemoteProcedure(RemoteProcedureBase):
    def __call__(self, *args, **kwargs):
        self.get_out_object(args, kwargs)
        self.get_out_string()
        out_string = ''.join(self.ctx.out_string)

        socket = context.socket(zmq.REQ)
        socket.connect(self.url)
        socket.send(out_string)

        self.ctx.in_string = socket.recv()
        self.get_in_object()

        if not (self.ctx.in_error is None):
            raise self.ctx.in_error
        else:
            return self.ctx.in_object

class ZeroMQClient(ClientBase):
    def __init__(self, url, app):
        ClientBase.__init__(self, url, app)

        self.service = Service(_RemoteProcedure, url, app)
